Struct Grammar

pub struct Grammar { /* private fields */ }
Grammar represents a context-free grammar.

It tracks a set of symbols and a set of production rules showing how those symbols interact.

Implementations

Source

impl Grammar

pub fn new() -> GrammarBuilder

A builder API for creating a Grammar object.

pub fn symbols(&self) -> Vec<Symbol<'_>>

The set of symbols.

pub fn terminals(&self) -> Vec<Symbol<'_>>

The set of terminal symbols.

pub fn nonterminals(&self) -> Vec<Symbol<'_>>

The set of nonterminal symbols.

pub fn rules(&self) -> Vec<Rule<'_>>

The set of rules.

pub fn symbol<S: AsRef<str>>(&self, name: S) -> Option<Symbol<'_>>

Fetch the symbol with the given name if it exists.